@@ -23,24 +23,26 @@ draw.sp.case <- function(
 	straight.reverse,
 	reverse = FALSE,
 	category,
-	cat.default.pos = "outer",
+	cat.default.pos = 'outer',
 	lwd = rep(2, 3),
-	lty = rep("solid", 3),
-	col = rep("black", 3),
-	label.col = rep("black", 7),
+	lty = rep('solid', 3),
+	col = rep('black', 3),
+	label.col = rep('black', 7),
 	cex = rep(1, 7),
-	fontface = rep("plain", 7),
-	fontfamily = rep("serif", 7),
+	fontface = rep('plain', 7),
+	fontfamily = rep('serif', 7),
 	cat.pos = c(-40, 40, 0),
 	cat.dist = c(0.05, 0.05, 0.025),
-	cat.col = rep("black", 3),
+	cat.col = rep('black', 3),
 	cat.cex = rep(1, 3),
-	cat.fontface = rep("plain", 3),
-	cat.fontfamily = rep("serif", 3),
+	cat.fontface = rep('plain', 3),
+	cat.fontfamily = rep('serif', 3),
 	cat.just = list(c(0.5, 1), c(0.5, 1), c(0.5, 0)),
 	cat.prompts = FALSE,
 	fill = NULL,
 	alpha = rep(0.5, 3),
+	print.mode = 'raw',
+    sigdigs=3,
 	...
 	) {
 
@@ -84,25 +86,44 @@ draw.sp.case <- function(
 		}
 
 	# add the text labels
-	for (i in 1:7) {
-		if (i %in% enabled.areas) {
-			grob.list <- gList(
-				grob.list,
-				textGrob(
-					label = area.list[i],
-					x = area.x[i],
-					y = area.y[i],
-					just = c('centre', 'centre'),
-					gp = gpar(
-						col = label.col[i],
-						cex = cex[i],
-						fontface = fontface[i],
-						fontfamily = fontfamily[i]
-						)
-					)
-				);
+	# make it percents if it is enabled
+	# else give the count number
+	processedLabels <- rep('',length(area.list));
+    if(print.mode[1] == 'percent'){
+			processedLabels <- paste(signif(area.list/sum(area.list)*100,digits=sigdigs),'%',sep='');
+			if(isTRUE(print.mode[2] == 'raw'))
+			{
+				processedLabels <- paste(processedLabels,'\n(',area.list,')',sep='');
 			}
 		}
+	if(print.mode[1] == 'raw'){
+			processedLabels <- area.list;
+			if(isTRUE(print.mode[2] == 'percent'))
+			{
+				processedLabels <- paste(processedLabels,'\n(',paste(signif(area.list/sum(area.list)*100,digits=sigdigs),'%)',sep=''),sep='');
+			}
+		}
+	
+	for (i in 1:7) {
+			if (i %in% enabled.areas) {
+				grob.list <- gList(
+					grob.list,
+					textGrob(
+						label = processedLabels[i],
+						x = area.x[i],
+						y = area.y[i],
+						just = c('centre', 'centre'),
+						gp = gpar(
+							col = label.col[i],
+							cex = cex[i],
+							fontface = fontface[i],
+							fontfamily = fontfamily[i]
+							)
+						)
+					);
+				}
+			}
+		
 
 	# create category labels
 	for (i in 1:3) {
@@ -126,7 +147,8 @@ draw.sp.case <- function(
 				);
 			}
 		else {
-			stop('Invalid cat.default.pos setting');
+			flog.error('Invalid cat.default.pos setting',name='VennDiagramLogger')
+stop('Invalid cat.default.pos setting');
 			}
 
 		# create the label
